@@ -75,6 +75,7 @@
 #define SHOW_SCREEN_KEY	"/apps/fast-user-switch-applet/show_screen_item"
 #define ACTIVE_ONLY_KEY	"/apps/fast-user-switch-applet/show_active_users_only"
 
+
 /* ******************** *
  *  Private Structures  *
  * ******************** */
@@ -455,7 +456,7 @@ applet_fill_cb (PanelApplet *applet,
 	    g_signal_connect (user, "notify::display-name",
 			      G_CALLBACK (user_notify_display_name_cb),
 			      adata->imglabel);
-	  gtk_box_pack_start (GTK_BOX (hbox), adata->imglabel, TRUE, TRUE, 3);
+	  gtk_box_pack_start (GTK_BOX (hbox), adata->imglabel, TRUE, TRUE, 0);
 	  gtk_widget_show (adata->imglabel);
 	}
       else if (strcmp (value, "icon") == 0)
@@ -468,14 +469,14 @@ applet_fill_cb (PanelApplet *applet,
       else
 	{
 	  adata->imglabel = gtk_label_new (_("Users"));
-	  gtk_box_pack_start (GTK_BOX (hbox), adata->imglabel, TRUE, TRUE, 3);
+	  gtk_box_pack_start (GTK_BOX (hbox), adata->imglabel, TRUE, TRUE, 0);
 	  gtk_widget_show (adata->imglabel);
 	}
     }
   else
     {
       adata->imglabel = gtk_label_new (_("Users"));
-      gtk_box_pack_start (GTK_BOX (hbox), adata->imglabel, TRUE, TRUE, 3);
+      gtk_box_pack_start (GTK_BOX (hbox), adata->imglabel, TRUE, TRUE, 0);
       gtk_widget_show (adata->imglabel);
     }
   g_free (value);
@@ -603,11 +604,32 @@ set_menuitem_icon (BonoboUIComponent *component,
 		   gint               icon_size)
 {
   GdkPixbuf *pixbuf;
+  gint width, height;
 
   pixbuf = gtk_icon_theme_load_icon (theme, icon_name, icon_size, 0, NULL);
   if (!pixbuf)
     return;
 
+  width = gdk_pixbuf_get_width (pixbuf);
+  height = gdk_pixbuf_get_height (pixbuf);
+  if (width > icon_size + 4 || height > icon_size + 4)
+    {
+      GdkPixbuf *tmp;
+      if (height > width)
+        {
+	  width *= (gdouble) icon_size / (gdouble) height;
+	  height = icon_size;
+	}
+      else
+        {
+	  height *= (gdouble) icon_size / (gdouble) width;
+	  width = icon_size;
+	}
+      tmp = gdk_pixbuf_scale_simple (pixbuf, width, height, GDK_INTERP_BILINEAR);
+      g_object_unref (pixbuf);
+      pixbuf = tmp;
+    }
+
   bonobo_ui_util_set_pixbuf (component, item_path, pixbuf, NULL);
   g_object_unref (pixbuf);
 }
@@ -810,7 +832,7 @@ applet_size_allocate_cb (GtkWidget     *widget,
   if (GTK_IS_IMAGE (adata->imglabel))
     {
       gtk_image_set_pixel_size (GTK_IMAGE (adata->imglabel),
-                                pixel_size);
+				pixel_size - 4);
     }
   else
     {
@@ -1322,7 +1344,7 @@ client_notify_applet_func (GConfClient *client,
 				      G_CALLBACK (user_notify_display_name_cb),
 				      adata->imglabel);
 		  gtk_box_pack_start (GTK_BOX (parent), adata->imglabel,
-				      TRUE, TRUE, 3);
+				      TRUE, TRUE, 0);
 		  gtk_widget_show (adata->imglabel);
 		}
 	      else if (!adata->user_notify_id)
@@ -1357,10 +1379,8 @@ client_notify_applet_func (GConfClient *client,
 		  adata->imglabel =
 		    gtk_image_new_from_icon_name ("stock_people",
 						  GTK_ICON_SIZE_MENU);
-		  gtk_image_set_pixel_size (GTK_IMAGE (adata->imglabel),
-					    adata->pixel_size + item_border);
 		  gtk_box_pack_start (GTK_BOX (parent), adata->imglabel,
-				      TRUE, TRUE, 3);
+				      TRUE, TRUE, 0);
 		  gtk_widget_show (adata->imglabel);
 		}
 	    }
@@ -1377,7 +1397,7 @@ client_notify_applet_func (GConfClient *client,
 		  gtk_widget_destroy (adata->imglabel);
 		  adata->imglabel = gtk_label_new (_("Users"));
 		  gtk_box_pack_start (GTK_BOX (parent), adata->imglabel,
-				      TRUE, TRUE, 3);
+				      TRUE, TRUE, 0);
 		  gtk_widget_show (adata->imglabel);
 		}
 	    }
@@ -1395,7 +1415,7 @@ client_notify_applet_func (GConfClient *client,
 	      gtk_widget_destroy (adata->imglabel);
 	      adata->imglabel = gtk_label_new (_("Users"));
 	      gtk_box_pack_start (GTK_BOX (parent), adata->imglabel,
-				  TRUE, TRUE, 3);
+				  TRUE, TRUE, 0);
 	      gtk_widget_show (adata->imglabel);
 	    }
 	}
@@ -1637,8 +1657,14 @@ menuitem_destroy_cb (GtkWidget *menuitem,
   adata = data;
 
   if (FUSA_IS_USER_MENU_ITEM (menuitem))
-    g_object_set_qdata (G_OBJECT (fusa_user_menu_item_get_user (FUSA_USER_MENU_ITEM (menuitem))),
-			adata->user_menu_item_quark, NULL);
+    {
+      FusaUser *user;
+      
+      user = fusa_user_menu_item_get_user (FUSA_USER_MENU_ITEM (menuitem));
+      if (user)
+        g_object_set_qdata (G_OBJECT (user),
+			    adata->user_menu_item_quark, NULL);
+    }
 
   li = g_slist_find (adata->items, menuitem);
   adata->items = g_slist_delete_link (adata->items, li);
@@ -1670,6 +1696,7 @@ menuitem_style_set_cb (GtkWidget *menuitem,
 	icon_name = GTK_STOCK_MISSING_IMAGE;
 
       image = gtk_image_menu_item_get_image (GTK_IMAGE_MENU_ITEM (menuitem));
+      gtk_image_set_pixel_size (GTK_IMAGE (image), adata->pixel_size);
       gtk_image_set_from_icon_name (GTK_IMAGE (image), icon_name,
 				    adata->icon_size);
     }
@@ -2250,6 +2277,10 @@ static void
 maybe_lock_screen (FusaAppletData *adata,
 		   FusaDisplay    *display)
 {
+//  g_message ("Trying to lock screen, lock-key = %d, nested = %d.",
+//	     panel_applet_gconf_get_bool (adata->applet, LOCK_KEY, NULL),
+//	     fusa_display_get_nested (display));
+
   if (panel_applet_gconf_get_bool (adata->applet, LOCK_KEY, NULL) &&
       !fusa_display_get_nested (display))
     {
@@ -2259,11 +2290,14 @@ maybe_lock_screen (FusaAppletData *adata,
       gboolean use_gscreensaver = TRUE;
 
       args[0] = g_find_program_in_path ("gnome-screensaver-command");
+      g_message ("gnome-screensaver-command = `%s'", args[0]);
       if (!args[0])
         {
           args[0] = g_find_program_in_path ("xscreensaver-command");
+          g_message ("xscreensaver-command = `%s'", args[0]);
           use_gscreensaver = FALSE;
         }
+
       if (!args[0])
 	return;
 
@@ -2279,9 +2313,7 @@ maybe_lock_screen (FusaAppletData *adata,
 	screen = gdk_screen_get_default ();
 
       err = NULL;
-      if (!gdk_spawn_on_screen (screen, g_get_home_dir (), args, NULL,
-				(G_SPAWN_STDERR_TO_DEV_NULL |
-				 G_SPAWN_STDOUT_TO_DEV_NULL),
+      if (!gdk_spawn_on_screen (screen, g_get_home_dir (), args, NULL, 0,
 				NULL, NULL, NULL, &err))
 	{
 	  g_warning (_("Can't lock screen: %s"), err->message);
@@ -2293,9 +2325,7 @@ maybe_lock_screen (FusaAppletData *adata,
       else
 	args[1] = "-throttle";
 
-      if (!gdk_spawn_on_screen (screen, g_get_home_dir (), args, NULL,
-				(G_SPAWN_STDERR_TO_DEV_NULL |
-				 G_SPAWN_STDOUT_TO_DEV_NULL),
+      if (!gdk_spawn_on_screen (screen, g_get_home_dir (), args, NULL, 0,
 				NULL, NULL, NULL, &err))
 	{
 	  g_warning (_("Can't temporarily set screensaver to blank screen: %s"),
@@ -2311,14 +2341,13 @@ static gboolean
 system_can_do_xnest (void)
 {
   gchar *tmp;
+  gboolean retval;
 
   tmp = g_find_program_in_path ("Xnest");
+  retval = (tmp != NULL ? TRUE : FALSE);
   g_free (tmp);
 
-  if (!tmp && g_file_test ("/usr/X11R6/bin/Xnest", G_FILE_TEST_EXISTS))
-    tmp = GUINT_TO_POINTER (!NULL);
-
-  return (tmp != NULL);
+  return retval;
 }
 
 static void
